<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../directorymenu.cpp" line="126"/>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <location filename="../directorymenu.cpp" line="130"/>
        <source>Open in terminal</source>
        <translation>Openen in terminalvenster</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>Mapmenu-instellingen</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Vormgeving</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>Hoofdmap:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>Naam van hoofdmap</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>Pictogram:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="66"/>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="86"/>
        <source>Button style</source>
        <translation>Knopstijl</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="103"/>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="96"/>
        <location filename="../directorymenuconfiguration.cpp" line="131"/>
        <source>Choose Default Terminal</source>
        <translation>Kies standaard terminalprogramma</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="54"/>
        <source>Only icon</source>
        <translation>Alleen pictogrammen</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="55"/>
        <source>Only text</source>
        <translation>Alleen tekst</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="56"/>
        <source>Icon and text</source>
        <translation>Pictogrammen en tekst</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="115"/>
        <source>Choose Base Directory</source>
        <translation>Kies een hoofdmap</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="164"/>
        <source>Choose Icon</source>
        <translation>Kies een pictogram</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="164"/>
        <source>Icons (*.png *.xpm *.jpg *.svg)</source>
        <translation>Pictogrammen (*.png *.xpm *.jpg *.svg)</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="188"/>
        <source>Choose Label</source>
        <translation>Voer een labelnaam in</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="189"/>
        <source>Label:</source>
        <translation>Label:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="173"/>
        <source>Directory Menu</source>
        <translation>Mapmenu</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="173"/>
        <source>An error occurred while loading the icon.</source>
        <translation>Er is een fout opgetreden bij het laden van het pictogram.</translation>
    </message>
</context>
</TS>
